@@ -12,8 +12,3 @@ def findArucoMarkers(img, markerSize, totalMarkers=250, draw=True):
     if draw:
         aruco.drawDetectedMarkers(img, bboxs)
     return bboxs[0][0]
-
-
-img = cv2.imread("2.png")
-
-print(findArucoMarkers(img,6))
\ No newline at end of file
